@@ -1,9 +1,7 @@
 use strict;
 use warnings;
 package Software::License::GPL_2;
-{
-  $Software::License::GPL_2::VERSION = '0.103008';
-}
+$Software::License::GPL_2::VERSION = '0.103010';
 use parent 'Software::License';
 # ABSTRACT: GNU General Public License, Version 2
 
@@ -16,13 +14,15 @@ sub meta2_name { 'gpl_2' }
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Software::License::GPL_2 - GNU General Public License, Version 2
 
 =head1 VERSION
 
-version 0.103008
+version 0.103010
 
 =head1 AUTHOR
 
@@ -30,7 +30,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -43,7 +43,7 @@ __LICENSE__
                        Version 2, June 1991
 
  Copyright (C) 1989, 1991 Free Software Foundation, Inc.,
- 51 Franklin St, Suite 500, Boston, MA  02110-1335  USA
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  Everyone is permitted to copy and distribute verbatim copies
  of this license document, but changing it is not allowed.
 
